@@ -8,27 +8,15 @@
 #   The Artistic License 2.0 (GPL Compatible)
 #
 package Moo::Lax;
-{
-  $Moo::Lax::VERSION = '0.15';
-}
 
 #ABSTRACT: Loads Moo without turning warnings to fatal.
 
 
-use strict;
-use warnings;
-
-use Moo ();
+our $VERSION = 2;
+use Moo 2 ();
 use Import::Into;
 
-sub import {
-    no warnings 'uninitialized';
-    my $previous_bits = ${^WARNING_BITS} & $warnings::DeadBits{all};
-    local $ENV{PERL_STRICTURES_EXTRA} = 0;
-    Moo->import::into(caller, @_);
-    ${^WARNING_BITS} &= ~$warnings::DeadBits{all} | $previous_bits;
-    return;
-}
+sub import { Moo->import::into(caller, @_); return }
 
 1;
 
@@ -44,7 +32,7 @@ Moo::Lax - Loads Moo without turning warnings to fatal.
 
 =head1 VERSION
 
-version 0.15
+version 2.00
 
 =head1 SYNOPSIS
 
@@ -57,6 +45,17 @@ By default Moo turns all warnings to fatal warnings. C<Moo::Lax> is exactly the
 same as C<Moo>, except that it doesn't turn all warnings to fatal warnings in
 the calling module.
 
+=head1 DEPRECATED
+
+With the release of L<Moo> version 2, C<use Moo> no longer imports
+L<strictures> by default and therefore warnings are not fatalised unless
+an explicit C<use strictures> is added to the code.
+
+As such, this module is no longer required - simply update your dependency
+on Moo to version 2 and switch back to plain C<use Moo> in your classes.
+
+Thus, as per version 2.00, this module simply requires L<Moo> version 2.
+
 =head1 CONTRIBUTORS
 
 =over
@@ -65,6 +64,10 @@ the calling module.
 
 Leon Timmermans
 
+=item *
+
+Olivier MenguÃ©
+
 =back
 
 =head1 AUTHOR
